﻿using Syncfusion.UI.Xaml.Grid;
using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Interactivity;

namespace DragDropBetweenDataGrids
{
    public class DragDropBehavior : Behavior<SfDataGrid>
    {
        protected override void OnAttached()
        {
            base.OnAttached();
            AssociatedObject.RowDragDropController.Dropped += sfGrid_Dropped;
        }

        /// <summary>
        /// Customize the Dropped event.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void sfGrid_Dropped(object sender, GridRowDroppedEventArgs e)
        {
            if (e.DropPosition != DropPosition.None)
            {
                //Get Dragging records
                ObservableCollection<object> draggingRecords = e.Data.GetData("Records") as ObservableCollection<object>;
                //Gets the TargetRecord from the underlying collection using record index of the TargetRecord (e.TargetRecord)
                ViewModel model = AssociatedObject.DataContext as ViewModel;
                OrderInfo targetRecord = model.OrdersFirstGrid[(int)e.TargetRecord];
                //Use Batch update to avoid data operatons in SfDataGrid during records removing and inserting
                AssociatedObject.BeginInit();
                //Removes the dragging records from the underlying collection
                foreach (OrderInfo item in draggingRecords)
                {
                    model.OrdersFirstGrid.Remove(item);
                }
                //Find the target record index after removing the records
                int targetIndex = model.OrdersFirstGrid.IndexOf(targetRecord);
                int insertionIndex = e.DropPosition == DropPosition.DropAbove ? targetIndex : targetIndex + 1;
                insertionIndex = insertionIndex < 0 ? 0 : insertionIndex;
                //Insert dragging records to the target position
                for (int i = draggingRecords.Count - 1; i >= 0; i--)
                {
                    model.OrdersFirstGrid.Insert(insertionIndex, draggingRecords[i] as OrderInfo);
                }
                AssociatedObject.EndInit();
            }
        }


        protected override void OnDetaching()
        {
            base.OnDetaching();
            AssociatedObject.RowDragDropController.Dropped -= sfGrid_Dropped;
        }
    }

}

